"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var platform_1 = require("tns-core-modules/platform");
var hockeyapp_common_1 = require("./hockeyapp.common");
var utils = require("tns-core-modules/utils/utils");
var APP_ID_KEY = "HockeyAppId";
var HockeyAppIOSPlugin = (function () {
    function HockeyAppIOSPlugin() {
        this.initDone = false;
        this.metricsManager = null;
        this.updateManager = null;
    }
    HockeyAppIOSPlugin.prototype.init = function (appId) {
        if (this.initDone) {
            console.log("HockeyAppIOSPlugin already initialized");
            return;
        }
        if (!platform_1.isIOS) {
            return;
        }
        try {
            if (!appId) {
                var mainBundle = utils.ios.getter(NSBundle, NSBundle.mainBundle);
                appId = mainBundle.infoDictionary.objectForKey(APP_ID_KEY);
            }
            if (!appId) {
                console.error("No HockeyApp app ID was found. Please set an entry in Info.plist with key " + APP_ID_KEY);
                return;
            }
            BITHockeyManager.sharedHockeyManager().configureWithIdentifier(appId);
            BITHockeyManager.sharedHockeyManager().startManager();
            BITHockeyManager.sharedHockeyManager().authenticator.authenticateInstallation();
            this.metricsManager = BITHockeyManager.sharedHockeyManager().metricsManager;
            this.updateManager = BITHockeyManager.sharedHockeyManager().updateManager;
            this.initDone = true;
        }
        catch (e) {
            console.error('Error during init of HockeyApp', e);
        }
    };
    HockeyAppIOSPlugin.prototype.trackEvent = function (eventName) {
        if (!this.metricsManager) {
            console.warn("Metrics manager is not initialized, event won't be tracked");
            return;
        }
        if (!eventName || !/^[a-zA-Z0-9_. -]+$/.test(eventName)) {
            console.warn("Invalid event name, it may not appear in HockeyApp");
        }
        this.metricsManager.trackEventWithName(eventName);
    };
    HockeyAppIOSPlugin.prototype.checkForUpdate = function () {
        if (!this.updateManager) {
            console.warn("Error update manager not initialized");
            return;
        }
        this.updateManager.checkForUpdate();
    };
    return HockeyAppIOSPlugin;
}());
exports.HockeyApp = hockeyapp_common_1.getInstance(HockeyAppIOSPlugin);
//# sourceMappingURL=hockeyapp.ios.js.map